# -*- coding: utf-8 -*-
# Generated by Django 1.11.12 on 2018-05-02 10:19
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    initial = True

    dependencies = [
    ]

    operations = [
        migrations.CreateModel(
            name='Movie',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('title', models.CharField(db_index=True, max_length=1024, unique=True)),
                ('external_id', models.CharField(db_index=True, max_length=2048, unique=True)),
            ],
        ),
    ]
