# -*- coding: utf-8 -*-
# Generated by Django 1.11.27 on 2020-01-02 11:16
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('movies', '0004_rename_external_id_legacy_id'),
    ]

    operations = [
        migrations.AlterField(
            model_name='movie',
            name='legacy_id',
            field=models.CharField(db_index=True, max_length=2048, null=True, unique=True),
        ),
        migrations.AddField(
            model_name='movie',
            name='external_id',
            field=models.CharField(db_index=True, max_length=2048, null=True, unique=True),
        ),
    ]
