# -*- coding: utf-8 -*-
# Generated by Django 1.11.27 on 2020-01-02 11:08
from __future__ import unicode_literals

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('movies', '0003_priceindex'),
    ]

    operations = [
        migrations.RenameField(
            model_name='movie',
            old_name='external_id',
            new_name='legacy_id',
        ),
        migrations.RunSQL(
            'ALTER INDEX IF EXISTS movies_movie_external_id_key '
            'RENAME TO movies_movie_legacy_id_key',
            'ALTER INDEX IF EXISTS movies_movie_legacy_id_key '
            'RENAME TO movies_movie_external_id_key'),
        migrations.RunSQL(
            'ALTER INDEX IF EXISTS movies_movie_external_id_f11489dd_like '
            'RENAME TO movies_movie_legacy_id_like',
            'ALTER INDEX IF EXISTS movies_movie_legacy_id_like '
            'RENAME TO movies_movie_external_id_f11489dd_like')
    ]
